From mboxrd@z Thu Jan  1 00:00:00 1970
From: Michael Forney <mforney@mforney.org>
To: list+catgirl@causal.agency
Subject: [PATCH 0/2] Improve compatibility with NetBSD libcurses
Date: Thu, 17 Jun 2021 11:21:41 -0700
Message-Id: <20210617182143.17471-1-mforney@mforney.org>
MIME-Version: 1.0
Content-Transfer-Encoding: 8bit

Here are a couple of patches I needed to get catgirl working well
with NetBSD libcurses.

Other issues fixed in NetBSD trunk are:
PR 55457 (libcurses: when passed a pad, wget_wch/wgetch calls wrefresh on the pad)
PR 56224 (libcurses: adding character to last line of non-scrolling window wraps instead of truncates)

The last remaining issue I'm aware of is that vid_attr is not
implemented for the M-l listing. However, since it is just styling
for a non-critical feature, it seems acceptable for people who want
to use NetBSD libcurses to just patch those calls out themselves.

Michael Forney (2):
  Break out of input loop when UI is hidden
  Resize status window explicitly during resize()

 ui.c | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

-- 
2.31.1


From mboxrd@z Thu Jan  1 00:00:00 1970
From: Michael Forney <mforney@mforney.org>
To: list+catgirl@causal.agency
Subject: [PATCH 1/2] Break out of input loop when UI is hidden
Date: Thu, 17 Jun 2021 11:21:42 -0700
Message-Id: <20210617182143.17471-2-mforney@mforney.org>
In-Reply-To: <20210617182143.17471-1-mforney@mforney.org>
References: <20210617182143.17471-1-mforney@mforney.org>
MIME-Version: 1.0
Content-Transfer-Encoding: 8bit

Otherwise, wget_wch() is called immediately after hiding the UI
with M-l, which restores curses mode when using NetBSD's libcurses.
---
 ui.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/ui.c b/ui.c
index 8f8de1e..8d1f089 100644
--- a/ui.c
+++ b/ui.c
@@ -1075,7 +1075,7 @@ void uiRead(void) {
 
 	wint_t ch;
 	static bool paste, style, literal;
-	for (int ret; ERR != (ret = wget_wch(input, &ch));) {
+	for (int ret; !hidden && ERR != (ret = wget_wch(input, &ch));) {
 		if (ret == KEY_CODE_YES && ch == KeyPasteOn) {
 			paste = true;
 		} else if (ret == KEY_CODE_YES && ch == KeyPasteOff) {
-- 
2.31.1


From mboxrd@z Thu Jan  1 00:00:00 1970
Mime-Version: 1.0
Message-Id: <1b161dda-ad60-47ac-9b38-a6cbb60632af@www.fastmail.com>
In-Reply-To: <20210617182143.17471-2-mforney@mforney.org>
References: <20210617182143.17471-1-mforney@mforney.org>
 <20210617182143.17471-2-mforney@mforney.org>
Date: Thu, 17 Jun 2021 14:54:06 -0400
From: june <june@causal.agency>
To: "Michael Forney" <mforney@mforney.org>, list+catgirl@causal.agency
Subject: Re: [PATCH 1/2] Break out of input loop when UI is hidden
Content-Type: text/plain

On Thu, Jun 17, 2021, at 14:21, Michael Forney wrote:
> Otherwise, wget_wch() is called immediately after hiding the UI
> with M-l, which restores curses mode when using NetBSD's libcurses.

This seems to cause some weird behaviour on ncurses: pressing M-l
gets partway through printing the lines then stops in the middle
of a line. Pressing enter restores the UI, and on pressing M-l
again, scrolling up reveals the rest of the lines were printed at
*some* point. Very strange.

From mboxrd@z Thu Jan  1 00:00:00 1970
MIME-Version: 1.0
In-Reply-To: <1b161dda-ad60-47ac-9b38-a6cbb60632af@www.fastmail.com>
References: <20210617182143.17471-1-mforney@mforney.org> <20210617182143.17471-2-mforney@mforney.org>
 <1b161dda-ad60-47ac-9b38-a6cbb60632af@www.fastmail.com>
From: Michael Forney <mforney@mforney.org>
Date: Thu, 17 Jun 2021 12:19:20 -0700
Message-ID: <CAGw6cBupjAM_+Q4oV4CVrPiNG1xdQOBB0QypjK0QRha9i7KjZw@mail.gmail.com>
Subject: Re: [PATCH 1/2] Break out of input loop when UI is hidden
To: june <june@causal.agency>
Cc: list+catgirl@causal.agency
Content-Type: text/plain; charset="UTF-8"

On 2021-06-17, june <june@causal.agency> wrote:
> This seems to cause some weird behaviour on ncurses: pressing M-l
> gets partway through printing the lines then stops in the middle
> of a line. Pressing enter restores the UI, and on pressing M-l
> again, scrolling up reveals the rest of the lines were printed at
> *some* point. Very strange.

Interesting. Sorry, I should have tested that it didn't break ncurses.
I'll do some investigation to see if I can figure out what's going on,
then hopefully get back to you with a v2.

From mboxrd@z Thu Jan  1 00:00:00 1970
Content-Type: text/plain;
	charset=utf-8
Mime-Version: 1.0 (Mac OS X Mail 13.4 \(3608.120.23.2.7\))
Subject: Re: [PATCH 1/2] Break out of input loop when UI is hidden
From: june <june@causal.agency>
In-Reply-To: <CAGw6cBupjAM_+Q4oV4CVrPiNG1xdQOBB0QypjK0QRha9i7KjZw@mail.gmail.com>
Date: Wed, 23 Jun 2021 11:37:42 -0400
Cc: list+catgirl@causal.agency
Content-Transfer-Encoding: quoted-printable
Message-Id: <11646381-93F2-4020-B80D-23249B1AE25B@causal.agency>
References: <20210617182143.17471-1-mforney@mforney.org>
 <20210617182143.17471-2-mforney@mforney.org>
 <1b161dda-ad60-47ac-9b38-a6cbb60632af@www.fastmail.com>
 <CAGw6cBupjAM_+Q4oV4CVrPiNG1xdQOBB0QypjK0QRha9i7KjZw@mail.gmail.com>
To: Michael Forney <mforney@mforney.org>

> On Jun 17, 2021, at 15:19, Michael Forney <mforney@mforney.org> wrote:
>=20
> On 2021-06-17, june <june@causal.agency> wrote:
>> This seems to cause some weird behaviour on ncurses: pressing M-l
>> gets partway through printing the lines then stops in the middle
>> of a line. Pressing enter restores the UI, and on pressing M-l
>> again, scrolling up reveals the rest of the lines were printed at
>> *some* point. Very strange.
>=20
> Interesting. Sorry, I should have tested that it didn't break ncurses.
> I'll do some investigation to see if I can figure out what's going on,
> then hopefully get back to you with a v2.

Just updating/confirming that this only seems to be a problem in
xterm on OpenBSD (6.9, unconfirmed on -current, but xterm doesn=E2=80=99t
seem to have been changed since 6.9). The plot thicken.


From mboxrd@z Thu Jan  1 00:00:00 1970
From: Michael Forney <mforney@mforney.org>
To: list+catgirl@causal.agency
Subject: [PATCH 2/2] Resize status window explicitly during resize()
Date: Thu, 17 Jun 2021 11:21:43 -0700
Message-Id: <20210617182143.17471-3-mforney@mforney.org>
In-Reply-To: <20210617182143.17471-1-mforney@mforney.org>
References: <20210617182143.17471-1-mforney@mforney.org>
MIME-Version: 1.0
Content-Transfer-Encoding: 8bit

Although ncurses automatically resizes windows that extend to the
previous screen limits, NetBSD's libcurses does not, so resize the
status window explicitly.
---
 ui.c | 1 +
 1 file changed, 1 insertion(+)

diff --git a/ui.c b/ui.c
index 8d1f089..b7e7337 100644
--- a/ui.c
+++ b/ui.c
@@ -648,6 +648,7 @@ static void windowReflow(struct Window *window) {
 
 static void resize(void) {
 	wclear(main);
+	wresize(status, 1, COLS);
 	wresize(main, MAIN_LINES, COLS);
 	for (uint num = 0; num < windows.len; ++num) {
 		windowReflow(windows.ptrs[num]);
-- 
2.31.1


